@@ -3,6 +3,7 @@ function(sp.obj, name.var, listw.obj, flower=FALSE, locmoran=FALSE, names.arg=c(
 names.attr=names(sp.obj), criteria=NULL, carte=NULL, identify=FALSE, cex.lab=0.8, pch=16, col="lightblue3",
 xlab="", ylab="", axes=FALSE, lablong="", lablat="")
 {
+envir = as.environment(1)
 # Verification of the Spatial Object sp.obj
 class.obj<-class(sp.obj)[1]
 spdf<-(class.obj=="SpatialPolygonsDataFrame")
@@ -556,7 +557,7 @@ quitfunc2<-function()
     assign("GeoXp.open", FALSE, envir = baseenv())
     print("Results have been saved in last.select object")
     res<-list(obs=which(obs),MORAN=MORAN)
-    assign("last.select", res, envir = .GlobalEnv)
+    assign("last.select", res, envir = envir)
 }
 
 ####################################################
