@@ -1,7 +1,8 @@
-`mvariocloudmap` <- function(sp.obj, nb.obj, names.var, quantiles=NULL,
+`mvariocloudmap` <- function(sp.obj, nb.obj, names.var, quantiles=TRUE,
 names.attr=names(sp.obj), criteria=NULL, carte=NULL, identify=FALSE, cex.lab=0.8, pch=16, col="lightblue3",
 xlab="Pairwise spatial distances", ylab="Pairwise Mahalanobis distances", axes=FALSE, lablong="", lablat="")
 {
+envir = as.environment(1)
 # Verification of the Spatial Object sp.obj
 class.obj<-class(sp.obj)[1]
 
@@ -73,6 +74,7 @@ if(!(3%in%dev.list())) dev.new()
 # calcul des matrices theta et absvar
 
 n=nrow(dataset)
+p<-ncol(dataset)
 covr=covMcd(dataset,alpha=0.75)
 cinv=solve(covr$cov)
 
@@ -96,9 +98,21 @@ absvar<-absvar+t(absvar)
 # calcul des distances de Mahalanobis par site
 
 rd <- sqrt(mahalanobis(dataset, center = covr$center, cov = covr$cov))
-xarw <- arw(dataset, covr$center, covr$cov, alpha = 0.025)
-  ifelse(xarw$cn != Inf, alphab <- sqrt(c(xarw$cn, qchisq(c(0.75, 0.5, 0.25), ncol(dataset)))),
-  alphab <- sqrt(qchisq(c(0.975, 0.75, 0.5, 0.25), ncol(dataset))))
+
+pcrit<-ifelse(p <= 10,(0.24 - 0.003 * p)/sqrt(n), (0.252 - 0.0018 * p)/sqrt(n))
+ delta <- qchisq(1 - 0.025, p)
+ 
+ d2 <- mahalanobis(dataset, covr$center, covr$cov)
+ d2ord <- sort(d2)
+ dif <- pchisq(d2ord, p) - (0.5:n)/n
+ i <- (d2ord >= delta) & (dif > 0)
+ alfan<-ifelse(sum(i) == 0,0,max(dif[i]))
+ if (alfan < pcrit) 
+        alfan <- 0
+ cn<-ifelse(alfan > 0, max(d2ord[n - ceiling(n * alfan)], delta), Inf)
+
+alphab<-ifelse(cn != Inf, sqrt(c(cn, qchisq(c(0.75, 0.5, 0.25), ncol(dataset)))),sqrt(qchisq(c(0.975, 0.75, 0.5, 0.25), ncol(dataset))))
+
 
 
 chi2.quant<-rep(0,n)
@@ -118,19 +132,22 @@ lalpha <- length(alphab)
 ####################################################
 
 
-        u1 <- sort(theta)
-        u1 <- as.vector(u1)
-        z <- seq(1, max(u1), by = (max(u1)/3500))
-        z <- round(z)
-        z1 <- z[2:length(z)] - z[1:(length(z) - 1)]
-        h <- mean(z1)
-        p <- 1/(1 + (h^3/6))
-        p1 <- 1/(1 + (h^3/60))
-        p2 <- 1/(1 + (h^3/0.6))
-        alpha <- (1 - p)/p
-        borne1 <- (1 - p1)/p1
-        borne2 <- (1 - p2)/p2
+#        u1 <- sort(theta)
+#        u1 <- as.vector(u1)
+#        z <- seq(1, max(u1), by = (max(u1)/3500))
+#        z <- round(z)
+#        z1 <- z[2:length(z)] - z[1:(length(z) - 1)]
+#        h <- mean(z1)
+#        p <- 1/(1 + (h^3/6))
+#        p1 <- 1/(1 + (h^3/60))
+#        p2 <- 1/(1 + (h^3/0.6))
+#        alpha <- (1 - p)/p
+#        borne1 <- (1 - p1)/p1
+#        borne2 <- (1 - p2)/p2
 
+borne1=0.01
+borne2=0.99
+alpha=0.5
 ####################################################
 # slection d'un point sur la carte
 ####################################################
@@ -408,7 +425,7 @@ quitfunc2<-function()
     assign("GeoXp.open", FALSE, envir = baseenv())
     print("Results have been saved in last.select object")
     obs[lower.tri(obs)]<-FALSE
-    assign("last.select", which(obs,arr.ind=TRUE), envir = .GlobalEnv)
+    assign("last.select", which(obs,arr.ind=TRUE), envir = envir)
 }
 
 
